# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-16 14:38:22
:LastEditTime: 2021-04-14 16:06:52
:LastEditors: HuangJingCan
:description: 
"""
__all__ = ["act_s", "app_s", "base_s", "exchange_s", "goods_s", "machine_s", "order_s", "power_s", "price_s", "prize_s", "report_s", "series_s", "sms_s", "task_s", "theme_s", "throw_s", "user_s"]
